@@ -159,7 +159,7 @@ typedef struct {
 #define READ_BUFFER_SIZE 1024
 #define MASK_LENGTH 4
 
-G_DEFINE_TYPE_WITH_PRIVATE (SoupWebsocketConnection, soup_websocket_connection, G_TYPE_OBJECT)
+G_DEFINE_FINAL_TYPE_WITH_PRIVATE (SoupWebsocketConnection, soup_websocket_connection, G_TYPE_OBJECT)
 
 static void queue_frame (SoupWebsocketConnection *self, SoupWebsocketQueueFlags flags,
 			 gpointer data, gsize len, gsize amount);
@@ -1055,7 +1055,7 @@ process_frame (SoupWebsocketConnection *self)
 
 	/* Safety valve */
 	if (priv->max_incoming_payload_size > 0 &&
-	    payload_len >= priv->max_incoming_payload_size) {
+	    payload_len > priv->max_incoming_payload_size) {
 		too_big_error_and_close (self, payload_len);
 		return FALSE;
 	}
@@ -1726,8 +1726,8 @@ soup_websocket_connection_class_init (SoupWebsocketConnectionClass *klass)
  * @stream: a #GIOStream connected to the WebSocket server
  * @uri: the URI of the connection
  * @type: the type of connection (client/side)
- * @origin: (allow-none): the Origin of the client
- * @protocol: (allow-none): the subprotocol in use
+ * @origin: (nullable): the Origin of the client
+ * @protocol: (nullable): the subprotocol in use
  * @extensions: (element-type SoupWebsocketExtension) (transfer full): a #GList of #SoupWebsocketExtension objects
  *
  * Creates a #SoupWebsocketConnection on @stream with the given active @extensions.
@@ -2034,7 +2034,7 @@ soup_websocket_connection_send_message (SoupWebsocketConnection *self,
  * soup_websocket_connection_close:
  * @self: the WebSocket
  * @code: close code
- * @data: (allow-none): close data
+ * @data: (nullable): close data
  *
  * Close the connection in an orderly fashion.
  *
